@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2005-2007, Scientific Computing Associates, Inc.
+# Copyright (c) 2005-2009, REvolution Computing, Inc.
 #
 # NetWorkSpaces is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as published
@@ -16,6 +16,9 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 # USA
 #
+#pylint: disable-msg=C0103
+
+"""Configuration settings used throughout the NWS server."""
 
 import tempfile
 
@@ -24,3 +27,7 @@ nwsWebPort = 8766
 nwsWebServedDir = 'clientCode'
 nwsTmpDir = tempfile.gettempdir()
 nwsLongValueSize = 16 * 1024 * 1024
+nwsServerSslCert = None
+nwsServerSslKey  = None
+nwsPluginDirs = ['./plugins']
+debug = []
